newKeyLength top-level constant

int const newKeyLength

The number of random bytes behind a newly created key.

Keys are hashed to algKeyLength before use, so this is the real entropy of a secret, not the size of the AES key. It was 12 (96 bits) historically.

Implementation

const newKeyLength = 32;