utils/constants library
Constants
- algAuthTagLength → const int
- algIvLength → const int
- algKeyLength → const int
- keyIdDomain → const String
- Domain separator for the key fingerprint, so a key id can never be a prefix of the AES key itself.
- keyIdLength → const int
- Bytes of key fingerprint carried in a v1 secret.
- minKeyLength → const int
- The shortest key that will be accepted.
- newKeyLength → const int
- The number of random bytes behind a newly created key.
- secretAlg → const String
- secretHashAlg → const String