keyIdDomain top-level constant

String const keyIdDomain

Domain separator for the key fingerprint, so a key id can never be a prefix of the AES key itself.

Implementation

const keyIdDomain = 'pnv:key-id:v1';